@@ -169,7 +169,7 @@ class Foreperson:
                 self.data_source.origin.date = datetime.datetime.strptime(str(recipe['visit']['date']), '%Y-%m-%d')
                 self.data_source.origin.year = self.data_source.origin.date.year
             if 'local contact' in recipe['visit'].keys():
-                self.data_source = recipe['visit']['local contact']
+                self.data_source.origin.contact = recipe['visit']['local contact']
             if 'user' in recipe['visit'].keys():
                 self.creator.name = recipe['visit']['user']
             if 'affiliation' in recipe['visit'].keys():
